/*-------------------------------------------------------------------------+
| Copyright 2021 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.reuse.ui.utils;

import static org.eclipse.ui.IWorkbenchPage.VIEW_ACTIVATE;
import static org.eclipse.ui.IWorkbenchPage.VIEW_CREATE;
import static org.eclipse.ui.PlatformUI.getWorkbench;
import static org.fortiss.tooling.ext.reuse.ui.ToolingReuseUIActivator.getDefault;
import static org.fortiss.tooling.ext.reuse.ui.view.fx.IReuseLibraryViewPart.REUSE_LIBRARY_VIEW_ID;
import static org.fortiss.tooling.ext.reuse.ui.view.fx.ReuseLibraryFXViewPart.getReuseLibraryFXController;
import static org.fortiss.tooling.kernel.utils.LoggingUtils.info;

import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PartInitException;
import org.fortiss.tooling.ext.reuse.model.ReuseLibrary;
import org.fortiss.tooling.ext.reuse.ui.view.fx.ReuseLibraryFXController;

/**
 * Utility methods for the {@link ReuseLibrary} view.
 *
 * @author bergemann
 */
public class ReuseLibraryViewUtils {

	/** Ensures that the reuse library view is visible. */
	public static void raiseReuseLibraryView() {
		try {
			IWorkbenchPage activePage = getWorkbench().getActiveWorkbenchWindow().getActivePage();
			IViewPart reuseLibraryView = activePage.findView(REUSE_LIBRARY_VIEW_ID);
			if (reuseLibraryView == null) {
				activePage.showView(REUSE_LIBRARY_VIEW_ID, null, VIEW_CREATE);
			}
			activePage.showView(REUSE_LIBRARY_VIEW_ID, null, VIEW_ACTIVATE);
		} catch (PartInitException e) {
			info(getDefault(), "No reuse library view to display.");
		}
	}

	/**
	 * Ensures that the reuse library view is visible and also updates it (based on
	 * the underlying file structure).
	 */
	public static void raiseAndUpdateReuseLibraryView() {
		raiseReuseLibraryView();
		ReuseLibraryFXController reuseLibraryFXController = getReuseLibraryFXController();
		reuseLibraryFXController.updateReuseLibraryView();
	}
}
