/*-------------------------------------------------------------------------+
| Copyright 2021 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.reuse.compose;

import static org.fortiss.tooling.ext.reuse.utils.ReuseLibraryUtils.hasReusePossibility;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.base.compose.ModelElementCompositorBase;
import org.fortiss.tooling.ext.reuse.model.ReuseLibrary;
import org.fortiss.tooling.kernel.extension.IElementCompositor;
import org.fortiss.tooling.kernel.extension.data.IElementCompositionContext;
import org.fortiss.tooling.kernel.extension.data.Prototype;

/**
 * {@link IElementCompositor} implementation for the {@link ReuseLibrary}s.
 *
 * @author bergemann
 */
public class ReuseLibraryCompositor extends ModelElementCompositorBase<ReuseLibrary> {

	/** Checks composed element class (wit accepted/possible ones for reuse). */
	protected boolean isCorrectElementClass(EObject contained) {
		return hasReusePossibility(contained);
	}

	/** {@inheritDoc} */
	@Override
	public boolean canCompose(ReuseLibrary container, EObject contained, IElementCompositionContext context) {
		return isCorrectElementClass(contained);
	}

	/** {@inheritDoc} */
	@Override
	public boolean canComposePrototype(Prototype prototype) {
		return isCorrectElementClass(prototype.getPrototype());
	}

	/** {@inheritDoc} */
	@Override
	public boolean canDecompose(EObject contained) {
		return isCorrectElementClass(contained);
	}
}
