/*-------------------------------------------------------------------------+
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.views.library;

import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;

import org.conqat.ide.commons.ui.jface.TreeContentProviderBase;
import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.extension.data.ITopLevelElement;
import org.fortiss.tooling.kernel.model.ILibrary;
import org.fortiss.tooling.kernel.model.ILibraryElementReference;
import org.fortiss.tooling.kernel.service.IPersistencyService;
import org.fortiss.tooling.kernel.ui.extension.IModelElementHandler;
import org.fortiss.tooling.kernel.ui.internal.views.NavigatorTreeContentProvider;
import org.fortiss.tooling.kernel.ui.service.IModelElementHandlerService;

/**
 * Content provider for the library tree viewer. Reduced form of the
 * {@link NavigatorTreeContentProvider}.
 * 
 * @author eder
 */
public class LibraryTreeContentProvider extends TreeContentProviderBase {

	/** {@inheritDoc} */
	@Override
	public Object[] getElements(Object inputElement) {
		// delegate to the top-level element contexts of the persistency service
		List<Object> result = new LinkedList<Object>();
		for(ITopLevelElement context : IPersistencyService.getInstance().getTopLevelElements()) {
			EObject root = context.getRootModelElement();
			if(root instanceof ILibrary) {
				result.add(root);
			}
		}
		return result.toArray();
	}

	/** {@inheritDoc} */
	@Override
	public Object[] getChildren(Object parent) {
		// delegate to the model element handlers
		if(parent instanceof EObject) {
			EObject parentElement = (EObject)parent;
			if(parentElement instanceof ILibraryElementReference) {
				return new Object[0];
			}
			IModelElementHandler<EObject> handler =
					IModelElementHandlerService.getInstance().getModelElementHandler(parentElement);
			if(handler != null) {
				List<EObject> children = new ArrayList<EObject>();
				children.addAll(handler.getSubnodes(parentElement));
				children.addAll(handler.getSpecifications(parentElement));
				return children.toArray();
			}
		}
		return new Object[0];
	}

	/** {@inheritDoc} */
	@Override
	public Object getParent(Object element) {
		if(element instanceof EObject) {
			EObject me = (EObject)element;
			if(IPersistencyService.getInstance().isTopLevelElement(me)) {
				// delegate to persistency service
				return IPersistencyService.getInstance();
			}
			return me.eContainer();
		}
		return null;
	}
}
